@@ -386,6 +386,9 @@ r2.censReg <- function(model, ...) {
 #' @export
 r2.cpglm <- r2.censReg
 
+#' @export
+r2.serp <- r2.censReg
+
 #' @export
 r2.clm <- r2.censReg
 
@@ -467,9 +470,6 @@ r2.merMod <- function(model, ci = NULL, tolerance = 1e-5, ...) {
   r2_nakagawa(model, ci = ci, tolerance = tolerance, ...)
 }
 
-#' @export
-r2.glmmTMB <- r2.merMod
-
 #' @export
 r2.cpglmm <- r2.merMod
 
@@ -491,6 +491,48 @@ r2.MixMod <- r2.merMod
 #' @export
 r2.rlmerMod <- r2.merMod
 
+#' @export
+r2.glmmTMB <- function(model, ci = NULL, tolerance = 1e-5, verbose = TRUE, ...) {
+  # most models are mixed models
+  if (insight::is_mixed_model(model)) {
+    return(r2_nakagawa(model, ci = ci, tolerance = tolerance, ...))
+  } else {
+    if (!is.null(ci) && !is.na(ci)) {
+      return(.r2_ci(model, ci = ci, ...))
+    }
+    # calculate r2 for non-mixed glmmTMB models here -------------------------
+    info <- insight::model_info(model, verbose = FALSE)
+
+    if (info$is_linear) {
+      # for linear models, use the manual calculation
+      out <- .safe(.r2_lm_manual(model))
+    } else if (info$is_logit && info$is_bernoulli) {
+      # logistic regression with binary outcome
+      out <- list(R2_Tjur = r2_tjur(model, model_info = info, ...))
+      attr(out, "model_type") <- "Logistic"
+      names(out$R2_Tjur) <- "Tjur's R2"
+      class(out) <- c("r2_pseudo", class(out))
+    } else if (info$is_binomial && !info$is_bernoulli) {
+      # currently, non-bernoulli binomial models are not supported
+      if (verbose) {
+        insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
+      }
+      out <- NULL
+    } else if ((info$is_poisson && !info$is_zero_inflated) || info$is_exponential) {
+      # Poisson-regression or Gamma uses Nagelkerke's R2
+      out <- list(R2_Nagelkerke = r2_nagelkerke(model, ...))
+      names(out$R2_Nagelkerke) <- "Nagelkerke's R2"
+      attr(out, "model_type") <- "Generalized Linear"
+      class(out) <- c("r2_pseudo", class(out))
+    } else if (info$is_zero_inflated) {
+      # zero-inflated models use the default method
+      out <- r2_zeroinflated(model)
+    } else {
+      insight::format_error("`r2()` does not support models of class `glmmTMB` without random effects and this link-function.") # nolint
+    }
+  }
+  out
+}
 
 #' @export
 r2.wbm <- function(model, tolerance = 1e-5, ...) {
@@ -840,3 +882,43 @@ r2.DirichletRegModel <- function(model, ...) {
   }
   ci
 }
+
+
+.r2_lm_manual <- function(model) {
+  w <- insight::get_weights(model, verbose = FALSE)
+  r <- stats::residuals(model)
+  f <- stats::fitted(model)
+  n <- length(r)
+  rdf <- .safe(stats::df.residual(model))
+  df_int <- .safe(as.numeric(insight::has_intercept(model)))
+
+  if (insight::has_intercept(model)) {
+    if (is.null(w)) {
+      mss <- sum((f - mean(f))^2)
+    } else {
+      m <- sum(w * f / sum(w))
+      mss <- sum(w * (f - m)^2)
+    }
+  } else if (is.null(w)) {
+    mss <- sum(f^2)
+  } else {
+    mss <- sum(w * f^2)
+  }
+  if (is.null(w)) {
+    rss <- sum(r^2)
+  } else {
+    rss <- sum(w * r^2)
+  }
+  r_squared <- mss / (mss + rss)
+  if (is.null(df_int) || is.null(rdf)) {
+    adj_r2 <- NULL
+  } else {
+    adj_r2 <- 1 - (1 - r_squared) * ((n - df_int) / rdf)
+  }
+  out <- list(R2 = r_squared, R2_adjusted = adj_r2)
+
+  names(out$R2) <- "R2"
+  names(out$R2_adjusted) <- "adjusted R2"
+  attr(out, "model_type") <- "Linear"
+  structure(class = "r2_generic", out)
+}
