@@ -1,24 +1,24 @@
 #' @rdname test_performance
 #' @export
-test_wald <- function(...) {
+test_wald <- function(..., verbose = TRUE) {
   UseMethod("test_wald")
 }
 
 
 #' @export
-test_wald.default <- function(...) {
+test_wald.default <- function(..., verbose = TRUE) {
   # Attribute class to list and get names from the global environment
-  objects <- insight::ellipsis_info(..., only_models = TRUE)
+  my_objects <- insight::ellipsis_info(..., only_models = TRUE)
 
-  # Sanity checks (will throw error if non-valid objects)
-  .test_performance_checks(objects)
+  # validation checks (will throw error if non-valid objects)
+  my_objects <- .test_performance_checks(my_objects, verbose = verbose)
 
   # ensure proper object names
-  objects <- .check_objectnames(objects, sapply(match.call(expand.dots = FALSE)$`...`, as.character))
+  my_objects <- .check_objectnames(my_objects, sapply(match.call(expand.dots = FALSE)[["..."]], as.character))
 
   # If a suitable class is found, run the more specific method on it
-  if (inherits(objects, c("ListNestedRegressions", "ListNonNestedRegressions", "ListLavaan"))) {
-    test_wald(objects)
+  if (inherits(my_objects, c("ListNestedRegressions", "ListNonNestedRegressions", "ListLavaan"))) {
+    test_wald(my_objects)
   } else {
     insight::format_error("The models cannot be compared for some reason :/")
   }
@@ -27,18 +27,20 @@ test_wald.default <- function(...) {
 
 
 #' @export
-test_wald.ListNestedRegressions <- function(objects, ...) {
+test_wald.ListNestedRegressions <- function(objects, verbose = TRUE, ...) {
   # for binomial models, only chisq-test
   if (all(attributes(objects)$is_binomial)) {
-    insight::format_warning(
-      "Using Wald's F-Test is inappropriate for models with `binomial` family.",
-      "Running Likelihood Ratio Test (LRT) now."
-    )
+    if (verbose) {
+      insight::format_alert(
+        "Using Wald's F-Test is inappropriate for models with `binomial` family.",
+        "Running Likelihood Ratio Test (LRT) now."
+      )
+    }
     return(test_likelihoodratio(objects))
-  } else {
-    out <- .test_wald(objects, test = "F")
   }
 
+  out <- .test_wald(objects, test = "F")
+
   attr(out, "is_nested") <- TRUE
   class(out) <- c("test_performance", class(out))
   out
@@ -46,7 +48,7 @@ test_wald.ListNestedRegressions <- function(objects, ...) {
 
 
 #' @export
-test_wald.ListNonNestedRegressions <- function(objects, ...) {
+test_wald.ListNonNestedRegressions <- function(objects, verbose = TRUE, ...) {
   insight::format_error("Wald tests cannot be run on non-nested models. Try `test_vuong()`.")
 }
 
@@ -58,9 +60,9 @@ test_wald.ListNonNestedRegressions <- function(objects, ...) {
   dfs <- sapply(objects, insight::get_df, type = "residual")
 
   # sort by df
-  if (!all(sort(dfs) == dfs) && !all(sort(dfs) == rev(dfs))) {
+  if (is.unsorted(dfs) && is.unsorted(rev(dfs))) {
     objects <- objects[order(dfs)]
-    dfs <- dfs[order(dfs)]
+    dfs <- sort(dfs, na.last = TRUE)
   }
 
   dfs_diff <- c(NA, diff(sapply(objects, insight::get_df, type = "model")))
@@ -76,18 +78,18 @@ test_wald.ListNonNestedRegressions <- function(objects, ...) {
 
   # Find reference-model related stuff
   refmodel <- order(dfs)[1]
-  scale <- dev[refmodel] / dfs[refmodel]
+  my_scale <- dev[refmodel] / dfs[refmodel]
 
   # test = "F"
   if (test == "F") {
-    f_value <- (dev_diff / dfs_diff) / scale
+    f_value <- (dev_diff / dfs_diff) / my_scale
     f_value[!is.na(f_value) & f_value < 0] <- NA # rather than p = 0
-    out$`F` <- f_value
+    out[["F"]] <- f_value
     p <- stats::pf(f_value, abs(dfs_diff), dfs[refmodel], lower.tail = FALSE)
 
     # test = "LRT"
   } else {
-    chi2 <- dev_diff / scale * sign(dfs_diff)
+    chi2 <- dev_diff / my_scale * sign(dfs_diff)
     chi2[!is.na(chi2) & chi2 < 0] <- NA # rather than p = 0
     out$Chi2 <- chi2
     p <- stats::pchisq(chi2, abs(dfs_diff), lower.tail = FALSE)
